import { Http,Util } from '@/utils';
import EntityService from '../entity-service';



/**
 * 维护申请服务对象基类
 *
 * @export
 * @class EAMApplyServiceBase
 * @extends {EntityServie}
 */
export default class EAMApplyServiceBase extends EntityService {

    /**
     * Creates an instance of  EAMApplyServiceBase.
     * 
     * @param {*} [opts={}]
     * @memberof  EAMApplyServiceBase
     */
    constructor(opts: any = {}) {
        super(opts);
    }

    /**
     * 初始化基础数据
     *
     * @memberof EAMApplyServiceBase
     */
    public initBasicData(){
        this.APPLYDEKEY ='eamapply';
        this.APPDEKEY = 'eamapplyid';
        this.APPDENAME = 'eamapplies';
        this.APPDETEXT = 'eamapplyname';
        this.APPNAME = 'assetmanagement';
        this.SYSTEMNAME = 'ibizassetmanagement';
    }

// 实体接口

    /**
     * Select接口方法
     *
     * @param {*} [context={}]
     * @param {*} [data={}]
     * @param {boolean} [isloading]
     * @returns {Promise<any>}
     * @memberof EAMApplyServiceBase
     */
    public async Select(context: any = {},data: any = {}, isloading?: boolean): Promise<any> {
        if(context.eamlocation && context.eamasset && context.eamapply){
            let res:any = Http.getInstance().get(`/eamlocations/${context.eamlocation}/eamassets/${context.eamasset}/eamapplies/${context.eamapply}/select`,isloading);
            
            return res;
        }
        if(context.eamasset && context.eamapply){
            let res:any = Http.getInstance().get(`/eamassets/${context.eamasset}/eamapplies/${context.eamapply}/select`,isloading);
            
            return res;
        }
            let res:any = Http.getInstance().get(`/eamapplies/${context.eamapply}/select`,isloading);
            
            return res;
    }

    /**
     * Create接口方法
     *
     * @param {*} [context={}]
     * @param {*} [data={}]
     * @param {boolean} [isloading]
     * @returns {Promise<any>}
     * @memberof EAMApplyServiceBase
     */
    public async Create(context: any = {},data: any = {}, isloading?: boolean): Promise<any> {
        if(context.eamlocation && context.eamasset && true){
            let masterData:any = {};
            Object.assign(data,masterData);
            if(!data.srffrontuf || data.srffrontuf !== "1"){
                data[this.APPDEKEY] = null;
            }
            if(data.srffrontuf){
                delete data.srffrontuf;
            }
            let tempContext:any = JSON.parse(JSON.stringify(context));
            let res:any = await Http.getInstance().post(`/eamlocations/${context.eamlocation}/eamassets/${context.eamasset}/eamapplies`,data,isloading);
            this.tempStorage.setItem(tempContext.srfsessionkey+'_eamworkorders',JSON.stringify(res.data.eamworkorders?res.data.eamworkorders:[]));
            
            return res;
        }
        if(context.eamasset && true){
            let masterData:any = {};
            Object.assign(data,masterData);
            if(!data.srffrontuf || data.srffrontuf !== "1"){
                data[this.APPDEKEY] = null;
            }
            if(data.srffrontuf){
                delete data.srffrontuf;
            }
            let tempContext:any = JSON.parse(JSON.stringify(context));
            let res:any = await Http.getInstance().post(`/eamassets/${context.eamasset}/eamapplies`,data,isloading);
            this.tempStorage.setItem(tempContext.srfsessionkey+'_eamworkorders',JSON.stringify(res.data.eamworkorders?res.data.eamworkorders:[]));
            
            return res;
        }
        let masterData:any = {};
        Object.assign(data,masterData);
        if(!data.srffrontuf || data.srffrontuf !== "1"){
            data[this.APPDEKEY] = null;
        }
        if(data.srffrontuf){
            delete data.srffrontuf;
        }
        let tempContext:any = JSON.parse(JSON.stringify(context));
        let res:any = await Http.getInstance().post(`/eamapplies`,data,isloading);
        this.tempStorage.setItem(tempContext.srfsessionkey+'_eamworkorders',JSON.stringify(res.data.eamworkorders?res.data.eamworkorders:[]));
        
        return res;
    }

    /**
     * Update接口方法
     *
     * @param {*} [context={}]
     * @param {*} [data={}]
     * @param {boolean} [isloading]
     * @returns {Promise<any>}
     * @memberof EAMApplyServiceBase
     */
    public async Update(context: any = {},data: any = {}, isloading?: boolean): Promise<any> {
        if(context.eamlocation && context.eamasset && context.eamapply){
            let masterData:any = {};
            Object.assign(data,masterData);
            let res:any = await Http.getInstance().put(`/eamlocations/${context.eamlocation}/eamassets/${context.eamasset}/eamapplies/${context.eamapply}`,data,isloading);
            
            return res;
        }
        if(context.eamasset && context.eamapply){
            let masterData:any = {};
            Object.assign(data,masterData);
            let res:any = await Http.getInstance().put(`/eamassets/${context.eamasset}/eamapplies/${context.eamapply}`,data,isloading);
            
            return res;
        }
        let masterData:any = {};
        Object.assign(data,masterData);
            let res:any = await  Http.getInstance().put(`/eamapplies/${context.eamapply}`,data,isloading);
            
            return res;
    }

    /**
     * Remove接口方法
     *
     * @param {*} [context={}]
     * @param {*} [data={}]
     * @param {boolean} [isloading]
     * @returns {Promise<any>}
     * @memberof EAMApplyServiceBase
     */
    public async Remove(context: any = {},data: any = {}, isloading?: boolean): Promise<any> {
        if(context.eamlocation && context.eamasset && context.eamapply){
            let res:any = Http.getInstance().delete(`/eamlocations/${context.eamlocation}/eamassets/${context.eamasset}/eamapplies/${context.eamapply}`,isloading);
            return res;
        }
        if(context.eamasset && context.eamapply){
            let res:any = Http.getInstance().delete(`/eamassets/${context.eamasset}/eamapplies/${context.eamapply}`,isloading);
            return res;
        }
            let res:any = Http.getInstance().delete(`/eamapplies/${context.eamapply}`,isloading);
            return res;
    }

    /**
     * Get接口方法
     *
     * @param {*} [context={}]
     * @param {*} [data={}]
     * @param {boolean} [isloading]
     * @returns {Promise<any>}
     * @memberof EAMApplyServiceBase
     */
    public async Get(context: any = {},data: any = {}, isloading?: boolean): Promise<any> {
        if(context.eamlocation && context.eamasset && context.eamapply){
            let res:any = await Http.getInstance().get(`/eamlocations/${context.eamlocation}/eamassets/${context.eamasset}/eamapplies/${context.eamapply}`,isloading);
            
            return res;
        }
        if(context.eamasset && context.eamapply){
            let res:any = await Http.getInstance().get(`/eamassets/${context.eamasset}/eamapplies/${context.eamapply}`,isloading);
            
            return res;
        }
            let res:any = await Http.getInstance().get(`/eamapplies/${context.eamapply}`,isloading);
            
            return res;
    }

    /**
     * GetDraft接口方法
     *
     * @param {*} [context={}]
     * @param {*} [data={}]
     * @param {boolean} [isloading]
     * @returns {Promise<any>}
     * @memberof EAMApplyServiceBase
     */
    public async GetDraft(context: any = {},data: any = {}, isloading?: boolean): Promise<any> {
        if(context.eamlocation && context.eamasset && true){
            let res:any = await Http.getInstance().get(`/eamlocations/${context.eamlocation}/eamassets/${context.eamasset}/eamapplies/getdraft`,isloading);
            res.data.eamapply = data.eamapply;
            
            return res;
        }
        if(context.eamasset && true){
            let res:any = await Http.getInstance().get(`/eamassets/${context.eamasset}/eamapplies/getdraft`,isloading);
            res.data.eamapply = data.eamapply;
            
            return res;
        }
        let res:any = await  Http.getInstance().get(`/eamapplies/getdraft`,isloading);
        res.data.eamapply = data.eamapply;
        
        return res;
    }

    /**
     * CheckKey接口方法
     *
     * @param {*} [context={}]
     * @param {*} [data={}]
     * @param {boolean} [isloading]
     * @returns {Promise<any>}
     * @memberof EAMApplyServiceBase
     */
    public async CheckKey(context: any = {},data: any = {}, isloading?: boolean): Promise<any> {
        if(context.eamlocation && context.eamasset && context.eamapply){
            let masterData:any = {};
            Object.assign(data,masterData);
            let res:any = await Http.getInstance().post(`/eamlocations/${context.eamlocation}/eamassets/${context.eamasset}/eamapplies/${context.eamapply}/checkkey`,data,isloading);
            
            return res;
        }
        if(context.eamasset && context.eamapply){
            let masterData:any = {};
            Object.assign(data,masterData);
            let res:any = await Http.getInstance().post(`/eamassets/${context.eamasset}/eamapplies/${context.eamapply}/checkkey`,data,isloading);
            
            return res;
        }
            let res:any = Http.getInstance().post(`/eamapplies/${context.eamapply}/checkkey`,data,isloading);
            return res;
    }

    /**
     * Save接口方法
     *
     * @param {*} [context={}]
     * @param {*} [data={}]
     * @param {boolean} [isloading]
     * @returns {Promise<any>}
     * @memberof EAMApplyServiceBase
     */
    public async Save(context: any = {},data: any = {}, isloading?: boolean): Promise<any> {
        if(context.eamlocation && context.eamasset && context.eamapply){
            let masterData:any = {};
            Object.assign(data,masterData);
            let res:any = await Http.getInstance().post(`/eamlocations/${context.eamlocation}/eamassets/${context.eamasset}/eamapplies/${context.eamapply}/save`,data,isloading);
            
            return res;
        }
        if(context.eamasset && context.eamapply){
            let masterData:any = {};
            Object.assign(data,masterData);
            let res:any = await Http.getInstance().post(`/eamassets/${context.eamasset}/eamapplies/${context.eamapply}/save`,data,isloading);
            
            return res;
        }
        let masterData:any = {};
        Object.assign(data,masterData);
            let res:any = await  Http.getInstance().post(`/eamapplies/${context.eamapply}/save`,data,isloading);
            
            return res;
    }

    /**
     * FetchDefault接口方法
     *
     * @param {*} [context={}]
     * @param {*} [data={}]
     * @param {boolean} [isloading]
     * @returns {Promise<any>}
     * @memberof EAMApplyServiceBase
     */
    public async FetchDefault(context: any = {},data: any = {}, isloading?: boolean): Promise<any> {
        if(context.eamlocation && context.eamasset && true){
            let tempData:any = JSON.parse(JSON.stringify(data));
            let res:any = Http.getInstance().get(`/eamlocations/${context.eamlocation}/eamassets/${context.eamasset}/eamapplies/fetchdefault`,tempData,isloading);
            return res;
        }
        if(context.eamasset && true){
            let tempData:any = JSON.parse(JSON.stringify(data));
            let res:any = Http.getInstance().get(`/eamassets/${context.eamasset}/eamapplies/fetchdefault`,tempData,isloading);
            return res;
        }
        let tempData:any = JSON.parse(JSON.stringify(data));
        let res:any = Http.getInstance().get(`/eamapplies/fetchdefault`,tempData,isloading);
        return res;
    }
}