import { Http,Util } from '@/utils';
import EntityService from '../entity-service';



/**
 * 资产服务对象基类
 *
 * @export
 * @class EAMAssetServiceBase
 * @extends {EntityServie}
 */
export default class EAMAssetServiceBase extends EntityService {

    /**
     * Creates an instance of  EAMAssetServiceBase.
     * 
     * @param {*} [opts={}]
     * @memberof  EAMAssetServiceBase
     */
    constructor(opts: any = {}) {
        super(opts);
    }

    /**
     * 初始化基础数据
     *
     * @memberof EAMAssetServiceBase
     */
    public initBasicData(){
        this.APPLYDEKEY ='eamasset';
        this.APPDEKEY = 'assetid';
        this.APPDENAME = 'eamassets';
        this.APPDETEXT = 'assetname';
        this.APPNAME = 'assetmanagement';
        this.SYSTEMNAME = 'ibizassetmanagement';
    }

// 实体接口

    /**
     * Select接口方法
     *
     * @param {*} [context={}]
     * @param {*} [data={}]
     * @param {boolean} [isloading]
     * @returns {Promise<any>}
     * @memberof EAMAssetServiceBase
     */
    public async Select(context: any = {},data: any = {}, isloading?: boolean): Promise<any> {
        if(context.eamlocation && context.eamasset){
            let res:any = Http.getInstance().get(`/eamlocations/${context.eamlocation}/eamassets/${context.eamasset}/select`,isloading);
            
            return res;
        }
            let res:any = Http.getInstance().get(`/eamassets/${context.eamasset}/select`,isloading);
            
            return res;
    }

    /**
     * Create接口方法
     *
     * @param {*} [context={}]
     * @param {*} [data={}]
     * @param {boolean} [isloading]
     * @returns {Promise<any>}
     * @memberof EAMAssetServiceBase
     */
    public async Create(context: any = {},data: any = {}, isloading?: boolean): Promise<any> {
        if(context.eamlocation && true){
            let masterData:any = {};
            Object.assign(data,masterData);
            if(!data.srffrontuf || data.srffrontuf !== "1"){
                data[this.APPDEKEY] = null;
            }
            if(data.srffrontuf){
                delete data.srffrontuf;
            }
            let tempContext:any = JSON.parse(JSON.stringify(context));
            let res:any = await Http.getInstance().post(`/eamlocations/${context.eamlocation}/eamassets`,data,isloading);
            this.tempStorage.setItem(tempContext.srfsessionkey+'_eamapplies',JSON.stringify(res.data.eamapplies?res.data.eamapplies:[]));
            this.tempStorage.setItem(tempContext.srfsessionkey+'_eamassets',JSON.stringify(res.data.eamassets?res.data.eamassets:[]));
            this.tempStorage.setItem(tempContext.srfsessionkey+'_eamplans',JSON.stringify(res.data.eamplans?res.data.eamplans:[]));
            this.tempStorage.setItem(tempContext.srfsessionkey+'_eamworkorders',JSON.stringify(res.data.eamworkorders?res.data.eamworkorders:[]));
            
            return res;
        }
        let masterData:any = {};
        Object.assign(data,masterData);
        if(!data.srffrontuf || data.srffrontuf !== "1"){
            data[this.APPDEKEY] = null;
        }
        if(data.srffrontuf){
            delete data.srffrontuf;
        }
        let tempContext:any = JSON.parse(JSON.stringify(context));
        let res:any = await Http.getInstance().post(`/eamassets`,data,isloading);
        this.tempStorage.setItem(tempContext.srfsessionkey+'_eamapplies',JSON.stringify(res.data.eamapplies?res.data.eamapplies:[]));
        this.tempStorage.setItem(tempContext.srfsessionkey+'_eamassets',JSON.stringify(res.data.eamassets?res.data.eamassets:[]));
        this.tempStorage.setItem(tempContext.srfsessionkey+'_eamplans',JSON.stringify(res.data.eamplans?res.data.eamplans:[]));
        this.tempStorage.setItem(tempContext.srfsessionkey+'_eamworkorders',JSON.stringify(res.data.eamworkorders?res.data.eamworkorders:[]));
        
        return res;
    }

    /**
     * Update接口方法
     *
     * @param {*} [context={}]
     * @param {*} [data={}]
     * @param {boolean} [isloading]
     * @returns {Promise<any>}
     * @memberof EAMAssetServiceBase
     */
    public async Update(context: any = {},data: any = {}, isloading?: boolean): Promise<any> {
        if(context.eamlocation && context.eamasset){
            let masterData:any = {};
            Object.assign(data,masterData);
            let res:any = await Http.getInstance().put(`/eamlocations/${context.eamlocation}/eamassets/${context.eamasset}`,data,isloading);
            
            return res;
        }
        let masterData:any = {};
        Object.assign(data,masterData);
            let res:any = await  Http.getInstance().put(`/eamassets/${context.eamasset}`,data,isloading);
            
            return res;
    }

    /**
     * Remove接口方法
     *
     * @param {*} [context={}]
     * @param {*} [data={}]
     * @param {boolean} [isloading]
     * @returns {Promise<any>}
     * @memberof EAMAssetServiceBase
     */
    public async Remove(context: any = {},data: any = {}, isloading?: boolean): Promise<any> {
        if(context.eamlocation && context.eamasset){
            let res:any = Http.getInstance().delete(`/eamlocations/${context.eamlocation}/eamassets/${context.eamasset}`,isloading);
            return res;
        }
            let res:any = Http.getInstance().delete(`/eamassets/${context.eamasset}`,isloading);
            return res;
    }

    /**
     * Get接口方法
     *
     * @param {*} [context={}]
     * @param {*} [data={}]
     * @param {boolean} [isloading]
     * @returns {Promise<any>}
     * @memberof EAMAssetServiceBase
     */
    public async Get(context: any = {},data: any = {}, isloading?: boolean): Promise<any> {
        if(context.eamlocation && context.eamasset){
            let res:any = await Http.getInstance().get(`/eamlocations/${context.eamlocation}/eamassets/${context.eamasset}`,isloading);
            
            return res;
        }
            let res:any = await Http.getInstance().get(`/eamassets/${context.eamasset}`,isloading);
            
            return res;
    }

    /**
     * GetDraft接口方法
     *
     * @param {*} [context={}]
     * @param {*} [data={}]
     * @param {boolean} [isloading]
     * @returns {Promise<any>}
     * @memberof EAMAssetServiceBase
     */
    public async GetDraft(context: any = {},data: any = {}, isloading?: boolean): Promise<any> {
        if(context.eamlocation && true){
            let res:any = await Http.getInstance().get(`/eamlocations/${context.eamlocation}/eamassets/getdraft`,isloading);
            res.data.eamasset = data.eamasset;
            
            return res;
        }
        let res:any = await  Http.getInstance().get(`/eamassets/getdraft`,isloading);
        res.data.eamasset = data.eamasset;
        
        return res;
    }

    /**
     * CheckKey接口方法
     *
     * @param {*} [context={}]
     * @param {*} [data={}]
     * @param {boolean} [isloading]
     * @returns {Promise<any>}
     * @memberof EAMAssetServiceBase
     */
    public async CheckKey(context: any = {},data: any = {}, isloading?: boolean): Promise<any> {
        if(context.eamlocation && context.eamasset){
            let masterData:any = {};
            Object.assign(data,masterData);
            let res:any = await Http.getInstance().post(`/eamlocations/${context.eamlocation}/eamassets/${context.eamasset}/checkkey`,data,isloading);
            
            return res;
        }
            let res:any = Http.getInstance().post(`/eamassets/${context.eamasset}/checkkey`,data,isloading);
            return res;
    }

    /**
     * Save接口方法
     *
     * @param {*} [context={}]
     * @param {*} [data={}]
     * @param {boolean} [isloading]
     * @returns {Promise<any>}
     * @memberof EAMAssetServiceBase
     */
    public async Save(context: any = {},data: any = {}, isloading?: boolean): Promise<any> {
        if(context.eamlocation && context.eamasset){
            let masterData:any = {};
            Object.assign(data,masterData);
            let res:any = await Http.getInstance().post(`/eamlocations/${context.eamlocation}/eamassets/${context.eamasset}/save`,data,isloading);
            
            return res;
        }
        let masterData:any = {};
        Object.assign(data,masterData);
            let res:any = await  Http.getInstance().post(`/eamassets/${context.eamasset}/save`,data,isloading);
            
            return res;
    }

    /**
     * FetchChildAsset接口方法
     *
     * @param {*} [context={}]
     * @param {*} [data={}]
     * @param {boolean} [isloading]
     * @returns {Promise<any>}
     * @memberof EAMAssetServiceBase
     */
    public async FetchChildAsset(context: any = {},data: any = {}, isloading?: boolean): Promise<any> {
        if(context.eamlocation && true){
            let tempData:any = JSON.parse(JSON.stringify(data));
            let res:any = Http.getInstance().get(`/eamlocations/${context.eamlocation}/eamassets/fetchchildasset`,tempData,isloading);
            return res;
        }
        let tempData:any = JSON.parse(JSON.stringify(data));
        let res:any = Http.getInstance().get(`/eamassets/fetchchildasset`,tempData,isloading);
        return res;
    }

    /**
     * FetchDefault接口方法
     *
     * @param {*} [context={}]
     * @param {*} [data={}]
     * @param {boolean} [isloading]
     * @returns {Promise<any>}
     * @memberof EAMAssetServiceBase
     */
    public async FetchDefault(context: any = {},data: any = {}, isloading?: boolean): Promise<any> {
        if(context.eamlocation && true){
            let tempData:any = JSON.parse(JSON.stringify(data));
            let res:any = Http.getInstance().get(`/eamlocations/${context.eamlocation}/eamassets/fetchdefault`,tempData,isloading);
            return res;
        }
        let tempData:any = JSON.parse(JSON.stringify(data));
        let res:any = Http.getInstance().get(`/eamassets/fetchdefault`,tempData,isloading);
        return res;
    }
}