import { Http,Util } from '@/utils';
import EntityService from '../entity-service';



/**
 * 维护计划服务对象基类
 *
 * @export
 * @class EAMPlanServiceBase
 * @extends {EntityServie}
 */
export default class EAMPlanServiceBase extends EntityService {

    /**
     * Creates an instance of  EAMPlanServiceBase.
     * 
     * @param {*} [opts={}]
     * @memberof  EAMPlanServiceBase
     */
    constructor(opts: any = {}) {
        super(opts);
    }

    /**
     * 初始化基础数据
     *
     * @memberof EAMPlanServiceBase
     */
    public initBasicData(){
        this.APPLYDEKEY ='eamplan';
        this.APPDEKEY = 'eamplanid';
        this.APPDENAME = 'eamplans';
        this.APPDETEXT = 'eamplanname';
        this.APPNAME = 'assetmanagement';
        this.SYSTEMNAME = 'ibizassetmanagement';
    }

// 实体接口

    /**
     * Select接口方法
     *
     * @param {*} [context={}]
     * @param {*} [data={}]
     * @param {boolean} [isloading]
     * @returns {Promise<any>}
     * @memberof EAMPlanServiceBase
     */
    public async Select(context: any = {},data: any = {}, isloading?: boolean): Promise<any> {
        if(context.eamlocation && context.eamasset && context.eamplan){
            let res:any = Http.getInstance().get(`/eamlocations/${context.eamlocation}/eamassets/${context.eamasset}/eamplans/${context.eamplan}/select`,isloading);
            
            return res;
        }
        if(context.eamasset && context.eamplan){
            let res:any = Http.getInstance().get(`/eamassets/${context.eamasset}/eamplans/${context.eamplan}/select`,isloading);
            
            return res;
        }
            let res:any = Http.getInstance().get(`/eamplans/${context.eamplan}/select`,isloading);
            
            return res;
    }

    /**
     * Create接口方法
     *
     * @param {*} [context={}]
     * @param {*} [data={}]
     * @param {boolean} [isloading]
     * @returns {Promise<any>}
     * @memberof EAMPlanServiceBase
     */
    public async Create(context: any = {},data: any = {}, isloading?: boolean): Promise<any> {
        if(context.eamlocation && context.eamasset && true){
            let masterData:any = {};
            Object.assign(data,masterData);
            if(!data.srffrontuf || data.srffrontuf !== "1"){
                data[this.APPDEKEY] = null;
            }
            if(data.srffrontuf){
                delete data.srffrontuf;
            }
            let tempContext:any = JSON.parse(JSON.stringify(context));
            let res:any = await Http.getInstance().post(`/eamlocations/${context.eamlocation}/eamassets/${context.eamasset}/eamplans`,data,isloading);
            this.tempStorage.setItem(tempContext.srfsessionkey+'_eamplanlines',JSON.stringify(res.data.eamplanlines?res.data.eamplanlines:[]));
            this.tempStorage.setItem(tempContext.srfsessionkey+'_eamworkorders',JSON.stringify(res.data.eamworkorders?res.data.eamworkorders:[]));
            
            return res;
        }
        if(context.eamasset && true){
            let masterData:any = {};
            Object.assign(data,masterData);
            if(!data.srffrontuf || data.srffrontuf !== "1"){
                data[this.APPDEKEY] = null;
            }
            if(data.srffrontuf){
                delete data.srffrontuf;
            }
            let tempContext:any = JSON.parse(JSON.stringify(context));
            let res:any = await Http.getInstance().post(`/eamassets/${context.eamasset}/eamplans`,data,isloading);
            this.tempStorage.setItem(tempContext.srfsessionkey+'_eamplanlines',JSON.stringify(res.data.eamplanlines?res.data.eamplanlines:[]));
            this.tempStorage.setItem(tempContext.srfsessionkey+'_eamworkorders',JSON.stringify(res.data.eamworkorders?res.data.eamworkorders:[]));
            
            return res;
        }
        let masterData:any = {};
        Object.assign(data,masterData);
        if(!data.srffrontuf || data.srffrontuf !== "1"){
            data[this.APPDEKEY] = null;
        }
        if(data.srffrontuf){
            delete data.srffrontuf;
        }
        let tempContext:any = JSON.parse(JSON.stringify(context));
        let res:any = await Http.getInstance().post(`/eamplans`,data,isloading);
        this.tempStorage.setItem(tempContext.srfsessionkey+'_eamplanlines',JSON.stringify(res.data.eamplanlines?res.data.eamplanlines:[]));
        this.tempStorage.setItem(tempContext.srfsessionkey+'_eamworkorders',JSON.stringify(res.data.eamworkorders?res.data.eamworkorders:[]));
        
        return res;
    }

    /**
     * Update接口方法
     *
     * @param {*} [context={}]
     * @param {*} [data={}]
     * @param {boolean} [isloading]
     * @returns {Promise<any>}
     * @memberof EAMPlanServiceBase
     */
    public async Update(context: any = {},data: any = {}, isloading?: boolean): Promise<any> {
        if(context.eamlocation && context.eamasset && context.eamplan){
            let masterData:any = {};
            Object.assign(data,masterData);
            let res:any = await Http.getInstance().put(`/eamlocations/${context.eamlocation}/eamassets/${context.eamasset}/eamplans/${context.eamplan}`,data,isloading);
            
            return res;
        }
        if(context.eamasset && context.eamplan){
            let masterData:any = {};
            Object.assign(data,masterData);
            let res:any = await Http.getInstance().put(`/eamassets/${context.eamasset}/eamplans/${context.eamplan}`,data,isloading);
            
            return res;
        }
        let masterData:any = {};
        Object.assign(data,masterData);
            let res:any = await  Http.getInstance().put(`/eamplans/${context.eamplan}`,data,isloading);
            
            return res;
    }

    /**
     * Remove接口方法
     *
     * @param {*} [context={}]
     * @param {*} [data={}]
     * @param {boolean} [isloading]
     * @returns {Promise<any>}
     * @memberof EAMPlanServiceBase
     */
    public async Remove(context: any = {},data: any = {}, isloading?: boolean): Promise<any> {
        if(context.eamlocation && context.eamasset && context.eamplan){
            let res:any = Http.getInstance().delete(`/eamlocations/${context.eamlocation}/eamassets/${context.eamasset}/eamplans/${context.eamplan}`,isloading);
            return res;
        }
        if(context.eamasset && context.eamplan){
            let res:any = Http.getInstance().delete(`/eamassets/${context.eamasset}/eamplans/${context.eamplan}`,isloading);
            return res;
        }
            let res:any = Http.getInstance().delete(`/eamplans/${context.eamplan}`,isloading);
            return res;
    }

    /**
     * Get接口方法
     *
     * @param {*} [context={}]
     * @param {*} [data={}]
     * @param {boolean} [isloading]
     * @returns {Promise<any>}
     * @memberof EAMPlanServiceBase
     */
    public async Get(context: any = {},data: any = {}, isloading?: boolean): Promise<any> {
        if(context.eamlocation && context.eamasset && context.eamplan){
            let res:any = await Http.getInstance().get(`/eamlocations/${context.eamlocation}/eamassets/${context.eamasset}/eamplans/${context.eamplan}`,isloading);
            
            return res;
        }
        if(context.eamasset && context.eamplan){
            let res:any = await Http.getInstance().get(`/eamassets/${context.eamasset}/eamplans/${context.eamplan}`,isloading);
            
            return res;
        }
            let res:any = await Http.getInstance().get(`/eamplans/${context.eamplan}`,isloading);
            
            return res;
    }

    /**
     * GetDraft接口方法
     *
     * @param {*} [context={}]
     * @param {*} [data={}]
     * @param {boolean} [isloading]
     * @returns {Promise<any>}
     * @memberof EAMPlanServiceBase
     */
    public async GetDraft(context: any = {},data: any = {}, isloading?: boolean): Promise<any> {
        if(context.eamlocation && context.eamasset && true){
            let res:any = await Http.getInstance().get(`/eamlocations/${context.eamlocation}/eamassets/${context.eamasset}/eamplans/getdraft`,isloading);
            res.data.eamplan = data.eamplan;
            
            return res;
        }
        if(context.eamasset && true){
            let res:any = await Http.getInstance().get(`/eamassets/${context.eamasset}/eamplans/getdraft`,isloading);
            res.data.eamplan = data.eamplan;
            
            return res;
        }
        let res:any = await  Http.getInstance().get(`/eamplans/getdraft`,isloading);
        res.data.eamplan = data.eamplan;
        
        return res;
    }

    /**
     * CheckKey接口方法
     *
     * @param {*} [context={}]
     * @param {*} [data={}]
     * @param {boolean} [isloading]
     * @returns {Promise<any>}
     * @memberof EAMPlanServiceBase
     */
    public async CheckKey(context: any = {},data: any = {}, isloading?: boolean): Promise<any> {
        if(context.eamlocation && context.eamasset && context.eamplan){
            let masterData:any = {};
            Object.assign(data,masterData);
            let res:any = await Http.getInstance().post(`/eamlocations/${context.eamlocation}/eamassets/${context.eamasset}/eamplans/${context.eamplan}/checkkey`,data,isloading);
            
            return res;
        }
        if(context.eamasset && context.eamplan){
            let masterData:any = {};
            Object.assign(data,masterData);
            let res:any = await Http.getInstance().post(`/eamassets/${context.eamasset}/eamplans/${context.eamplan}/checkkey`,data,isloading);
            
            return res;
        }
            let res:any = Http.getInstance().post(`/eamplans/${context.eamplan}/checkkey`,data,isloading);
            return res;
    }

    /**
     * Save接口方法
     *
     * @param {*} [context={}]
     * @param {*} [data={}]
     * @param {boolean} [isloading]
     * @returns {Promise<any>}
     * @memberof EAMPlanServiceBase
     */
    public async Save(context: any = {},data: any = {}, isloading?: boolean): Promise<any> {
        if(context.eamlocation && context.eamasset && context.eamplan){
            let masterData:any = {};
            Object.assign(data,masterData);
            let res:any = await Http.getInstance().post(`/eamlocations/${context.eamlocation}/eamassets/${context.eamasset}/eamplans/${context.eamplan}/save`,data,isloading);
            
            return res;
        }
        if(context.eamasset && context.eamplan){
            let masterData:any = {};
            Object.assign(data,masterData);
            let res:any = await Http.getInstance().post(`/eamassets/${context.eamasset}/eamplans/${context.eamplan}/save`,data,isloading);
            
            return res;
        }
        let masterData:any = {};
        Object.assign(data,masterData);
            let res:any = await  Http.getInstance().post(`/eamplans/${context.eamplan}/save`,data,isloading);
            
            return res;
    }

    /**
     * FetchDefault接口方法
     *
     * @param {*} [context={}]
     * @param {*} [data={}]
     * @param {boolean} [isloading]
     * @returns {Promise<any>}
     * @memberof EAMPlanServiceBase
     */
    public async FetchDefault(context: any = {},data: any = {}, isloading?: boolean): Promise<any> {
        if(context.eamlocation && context.eamasset && true){
            let tempData:any = JSON.parse(JSON.stringify(data));
            let res:any = Http.getInstance().get(`/eamlocations/${context.eamlocation}/eamassets/${context.eamasset}/eamplans/fetchdefault`,tempData,isloading);
            return res;
        }
        if(context.eamasset && true){
            let tempData:any = JSON.parse(JSON.stringify(data));
            let res:any = Http.getInstance().get(`/eamassets/${context.eamasset}/eamplans/fetchdefault`,tempData,isloading);
            return res;
        }
        let tempData:any = JSON.parse(JSON.stringify(data));
        let res:any = Http.getInstance().get(`/eamplans/fetchdefault`,tempData,isloading);
        return res;
    }
}